@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+import asyncio
 import logging
 import os
 import threading
@@ -28,6 +29,7 @@ from ._constants import (
 from ._streaming import Stream
 
 from ._utils._key_agreement import key_agreement_client
+from ._utils._model_breaker import ModelBreaker
 
 __all__ = ["Ark", "AsyncArk"]
 
@@ -38,6 +40,10 @@ class Ark(SyncAPIClient):
     embeddings: resources.Embeddings
     tokenization: resources.Tokenization
     context: resources.Context
+    content_generation: resources.ContentGeneration
+    batch_chat: resources.BatchChat
+    model_breaker_map: dict[str, ModelBreaker]
+    model_breaker_lock: threading.Lock
 
     def __init__(
         self,
@@ -96,6 +102,10 @@ class Ark(SyncAPIClient):
         self.embeddings = resources.Embeddings(self)
         self.tokenization = resources.Tokenization(self)
         self.context = resources.Context(self)
+        self.content_generation = resources.ContentGeneration(self)
+        self.batch_chat = resources.BatchChat(self)
+        self.model_breaker_map = defaultdict(ModelBreaker)
+        self.model_breaker_lock = threading.Lock()
         # self.classification = resources.Classification(self)
 
     def _get_endpoint_sts_token(self, endpoint_id: str):
@@ -126,6 +136,9 @@ class Ark(SyncAPIClient):
         api_key = self.api_key
         return {"Authorization": f"Bearer {api_key}"}
 
+    def get_model_breaker(self, model_name: str) -> ModelBreaker:
+        with self.model_breaker_lock:
+            return self.model_breaker_map[model_name]
 
 class AsyncArk(AsyncAPIClient):
     chat: resources.AsyncChat
@@ -133,6 +146,10 @@ class AsyncArk(AsyncAPIClient):
     embeddings: resources.AsyncEmbeddings
     tokenization: resources.AsyncTokenization
     context: resources.AsyncContext
+    content_generation: resources.AsyncContentGeneration
+    batch_chat: resources.AsyncBatchChat
+    model_breaker_map: dict[str, ModelBreaker]
+    model_breaker_lock: asyncio.Lock
 
     def __init__(
         self,
@@ -190,6 +207,10 @@ class AsyncArk(AsyncAPIClient):
         self.embeddings = resources.AsyncEmbeddings(self)
         self.tokenization = resources.AsyncTokenization(self)
         self.context = resources.AsyncContext(self)
+        self.content_generation = resources.AsyncContentGeneration(self)
+        self.batch_chat = resources.AsyncBatchChat(self)
+        self.model_breaker_map = defaultdict(ModelBreaker)
+        self.model_breaker_lock = asyncio.Lock()
         # self.classification = resources.AsyncClassification(self)
 
     def _get_endpoint_sts_token(self, endpoint_id: str):
@@ -213,6 +234,10 @@ class AsyncArk(AsyncAPIClient):
         api_key = self.api_key
         return {"Authorization": f"Bearer {api_key}"}
 
+    async def get_model_breaker(self, model_name: str) -> ModelBreaker:
+        async with self.model_breaker_lock:
+            return self.model_breaker_map[model_name]
+
 
 class StsTokenManager(object):
     # The time at which we'll attempt to refresh, but not
