@@ -4,6 +4,8 @@ from .tokenization import Tokenization, AsyncTokenization
 from .classification import Classification, AsyncClassification
 from .bot import BotChat, AsyncBotChat
 from .context import Context, AsyncContext
+from .content_generation import ContentGeneration, AsyncContentGeneration
+from .batch_chat import BatchChat, AsyncBatchChat
 
 __all__ = [
     "Chat",
@@ -15,5 +17,9 @@ __all__ = [
     "Tokenization",
     "AsyncTokenization",
     "Context",
-    "AsyncContext"
+    "AsyncContext",
+    "ContentGeneration",
+    "AsyncContentGeneration"
+    "BatchChat",
+    "AsyncBatchChat"
 ]
